Please see [https://docs.mlcommons.org/cm4mlops/scripts/Compiler-automation/install-llvm-src](https://docs.mlcommons.org/cm4mlops/scripts/Compiler-automation/install-llvm-src) for the documentation of this CM script.
